CLI featuring:
* a builtin flask webserver, for automated and manual testing. Useful for development purposes.

In an initiated shell (see main README), start with: 

`python -m joop.cli --flask-server`